@@ -26,12 +26,11 @@ class NeuralTriGraphCentralVert():
             self.l_counts = distr_evenly(r_size, l_size)
 
 
-def distr_evenly(n, l):
-    ceil=np.ceil(n/l)
-    flr=ceil-1
-    h=int(n-l*flr)
-    j=int(l*ceil-n)
+def distr_evenly(n, le):
+    ceil = np.ceil(n/le)
+    flr = ceil-1
+    h = int(n-le*flr)
+    j = int(le*ceil-n)
     h_arr = np.ones(h)*ceil
     j_arr = np.ones(j)*flr
     return np.concatenate((h_arr, j_arr))
-
